==> totoui-0.3.0.tgz: package/lib/pagination.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _paginationItemJsx = require('./paginationItem.js');

var _paginationItemJsx2 = _interopRequireDefault(_paginationItemJsx);

var Pagination = (function (_React$Component) {
    _inherits(Pagination, _React$Component);

    function Pagination(props) {
        _classCallCheck(this, Pagination);

        _get(Object.getPrototypeOf(Pagination.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
        this.renderItem = this.renderItem.bind(this);
        this.handleChange = this.handleChange.bind(this);
        this.renderPages = this.renderPages.bind(this);
    }

    _createClass(Pagination, [{
        key: 'renderItem',
        value: function renderItem(type) {
            var data = this.props.data;

            return data && data[type + 'Title'] && data[type + 'Link'] ? _react2['default'].createElement(
                _paginationItemJsx2['default'],
                {
                    onClick: this.props.onSelect && this.props.onSelect.bind(this, data[type + 'Link']),
                    key: type,
                    href: data[type + 'Link'],
                    className: this.prefixClass(type) },
                data[type + 'Title']
            ) : null;
        }
    }, {
        key: 'handleChange',
        value: function handleChange(e) {
            if (this.props.onSelect) {
                var select = _react2['default'].findDOMNode(this.refs.select);

                this.props.onSelect.call(this, select && select.value, e);
            }
        }
    }, {
        key: 'renderPages',
        value: function renderPages() {
            var data = this.props.data;

            if (data.pages) {
                return this.props.theme === 'select' ? _react2['default'].createElement(
                    'li',
                    { className: this.prefixClass('select') },
                    _react2['default'].createElement(
                        'select',
                        {
                            onChange: this.handleChange,
                            ref: "select" },
                        data.pages.map(function (page, i) {
                            return _react2['default'].createElement(
                                'option',
                                { value: page.link, key: i },
                                page.title,
                                ' / ',
                                data.pages.length
                            );
                        })
                    )
                ) : data.pages.map((function (page, i) {
                    return _react2['default'].createElement(
                        _paginationItemJsx2['default'],
                        {
                            key: i,
                            onClick: this.props.onSelect && this.props.onSelect.bind(this, page.link),
                            active: page.active,
                            disabled: page.disabled,
                            href: page.link },
                        page.title
                    );
                }).bind(this));
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var props = this.props;
            var Component = props.componentTag;
            var classSet = this.getClassSet();
            var notSelect = props.theme !== 'select';

            // .am-pagination-right
            classSet[this.prefixClass('right')] = props.right;

            // .am-pagination-centered
            classSet[this.prefixClass('centered')] = props.centered;

            return props.data ? _react2['default'].createElement(
                Component,
                _extends({}, props, {
                    className: (0, _classnames2['default'])(classSet, props.className) }),
                notSelect && this.renderItem('first'),
                this.renderItem('prev'),
                this.renderPages(),
                this.renderItem('next'),
                notSelect && this.renderItem('last')
            ) : _react2['default'].createElement(
                Component,
                _extends({}, props, {
                    className: (0, _classnames2['default'])(classSet, props.className) }),
                this.props.children
            );
        }
    }]);

    return Pagination;
})(_react2['default'].Component);

Pagination.displayName = "Pagination";

Pagination.propTypes = {
    componentTag: _react2['default'].PropTypes.node.isRequired,
    centered: _react2['default'].PropTypes.bool,
    right: _react2['default'].PropTypes.bool,
    theme: _react2['default'].PropTypes.oneOf(['default', 'select']),
    data: _react2['default'].PropTypes.object,
    onSelect: _react2['default'].PropTypes.func
};

Pagination.defaultProps = {
    classPrefix: 'pagination',
    componentTag: 'ul'
};

module.exports = Pagination;

==> totoui-0.5.1.tgz: package/lib/pagination.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _paginationItemJsx = require('./paginationItem.js');

var _paginationItemJsx2 = _interopRequireDefault(_paginationItemJsx);

var Pagination = (function (_React$Component) {
    _inherits(Pagination, _React$Component);

    function Pagination(props) {
        _classCallCheck(this, Pagination);

        _get(Object.getPrototypeOf(Pagination.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
        this.renderItem = this.renderItem.bind(this);
        this.handleChange = this.handleChange.bind(this);
        this.renderPages = this.renderPages.bind(this);
    }

    _createClass(Pagination, [{
        key: 'renderItem',
        value: function renderItem(type) {
            var data = this.props.data;

            return data && data[type + 'Title'] && data[type + 'Link'] ? _react2['default'].createElement(
                _paginationItemJsx2['default'],
                {
                    onClick: this.props.onSelect && this.props.onSelect.bind(this, data[type + 'Link']),
                    key: type,
                    href: data[type + 'Link'],
                    className: this.prefixClass(type) },
                data[type + 'Title']
            ) : null;
        }
    }, {
        key: 'handleChange',
        value: function handleChange(e) {
            if (this.props.onSelect) {
                var select = _reactDom2['default'].findDOMNode(this.refs.select);

                this.props.onSelect.call(this, select && select.value, e);
            }
        }
    }, {
        key: 'renderPages',
        value: function renderPages() {
            var data = this.props.data;

            if (data.pages) {
                return this.props.theme === 'select' ? _react2['default'].createElement(
                    'li',
                    { className: this.prefixClass('select') },
                    _react2['default'].createElement(
                        'select',
                        {
                            onChange: this.handleChange,
                            ref: 'select' },
                        data.pages.map(function (page, i) {
                            return _react2['default'].createElement(
                                'option',
                                { value: page.link, key: i },
                                page.title,
                                ' / ',
                                data.pages.length
                            );
                        })
                    )
                ) : data.pages.map((function (page, i) {
                    return _react2['default'].createElement(
                        _paginationItemJsx2['default'],
                        {
                            key: i,
                            onClick: this.props.onSelect && this.props.onSelect.bind(this, page.link),
                            active: page.active,
                            disabled: page.disabled,
                            href: page.link },
                        page.title
                    );
                }).bind(this));
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var props = this.props;
            var Component = props.componentTag;
            var classSet = this.getClassSet();
            var notSelect = props.theme !== 'select';

            // .am-pagination-right
            classSet[this.prefixClass('right')] = props.right;

            // .am-pagination-centered
            classSet[this.prefixClass('centered')] = props.centered;

            return props.data ? _react2['default'].createElement(
                Component,
                _extends({}, props, {
                    className: (0, _classnames2['default'])(classSet, props.className) }),
                notSelect && this.renderItem('first'),
                this.renderItem('prev'),
                this.renderPages(),
                this.renderItem('next'),
                notSelect && this.renderItem('last')
            ) : _react2['default'].createElement(
                Component,
                _extends({}, props, {
                    className: (0, _classnames2['default'])(classSet, props.className) }),
                this.props.children
            );
        }
    }]);

    return Pagination;
})(_react2['default'].Component);

Pagination.displayName = "Pagination";

Pagination.propTypes = {
    componentTag: _react2['default'].PropTypes.node.isRequired,
    centered: _react2['default'].PropTypes.bool,
    right: _react2['default'].PropTypes.bool,
    theme: _react2['default'].PropTypes.oneOf(['default', 'select']),
    data: _react2['default'].PropTypes.object,
    onSelect: _react2['default'].PropTypes.func
};

Pagination.defaultProps = {
    classPrefix: 'pagination',
    componentTag: 'ul'
};

module.exports = Pagination;
